Skip to contents

Creates a new package with usethis::create_package() and applies an opinionated setup:

Usage

bootstrap_pkg(
  path,
  author_name = "Bjarke Hautop Kristensen",
  author_email = "bjarke.hautop@gmail.com",
  license = usethis::use_mit_license(),
  private = FALSE
)

Arguments

path

Path where the new package is created. The last component of the path is used as the package name.

author_name

Name of the package author (aut/cre in Authors@R and the license copyright holder).

author_email

Email of the package author.

license

A call to a usethis license function, e.g. usethis::use_mit_license() or usethis::use_gpl3_license().

private

Should the GitHub repository be private?

Value

The path to the new package, invisibly. The new package is left as the active usethis project and activated with usethis::proj_activate().

Details

It finishes by running the hooks once (letting the formatters fix up the scaffolded files), re-knitting the README, and committing and pushing the result.